
// Wait for startup
runOnStartup(async runtime =>
{
	runtime.addEventListener("beforeprojectstart", () => OnBeforeProjectStart(runtime));
});

async function OnBeforeProjectStart(runtime)
{
	// Update text object text
	const textInst = runtime.objects.Text.getFirstInstance();
	textInst.text = "Running benchmark...\n";
	
	// Run a short warmup to ensure CPU caches/JIT is working at peak performance
	let count = CountPrimesInRange(0, 10000);
	textInst.text += `Warmup: found ${count} primes\n`;
	
	// Run real benchmark, timing how long it takes to count all primes between
	// 1 million and 2 million
	const startTime = performance.now();
	
	count = CountPrimesInRange(1000000, 2000000);
	
	// Update text with timing result
	textInst.text += `Benchmark: found ${count} primes in ${Math.round(performance.now() - startTime)} ms\n`;
}

// Return the number of primes found in a number range.
function CountPrimesInRange(startNum, endNum)
{
	let primeCount = 0;
	for (let i = startNum; i < endNum; ++i)
	{
		if (IsPrime(i))
			primeCount++;
	}
	return primeCount;
}

// Determine if a given number is prime.
function IsPrime(n)
{
	if (n === 1)
		return true;
	if (n % 2 === 0)
		return false;
	
	const limit = Math.floor(Math.sqrt(n));
	for (let f = 3; f <= limit; f += 2)
	{
		if (n % f === 0)
			return false;
	}
	
	return true;
}